Dictionary-based helper for aligning your data to variables used in a script
dict_rename_helper(
dictionary,
varnames,
varnames_type,
rmd,
copy_to_clipboard = TRUE
)A dplyr command used to rename columns in your data frame according to the dictionary
A dataframe of the dictionary which you would like to use.
The name of dictionary column that contains variable names.
The name of dictionary column that contains the variable type.
This variable needs to be the same number of rows as as varnames.
Path to the Rmarkdown file which you would like to compare to.
if TRUE (default), the rename template will be
copied to the user's clipboard with clipr::write_clip(). If FALSE, the
rename template will be printed to the user's console.
read_dict()